Deutscher Bundestag - Namenslisten der Abstimmungen (PDF und XLSX-Listen)
Keywords: ,
Date: 01.02.2018

# Parlament

Bereich "" ein-/ausklappen
Startdatum im Format TT.MM.JJJJ
Enddatum im Format TT.MM.JJJJ

Veröffentlichung | Thema | Dokumentname | Dokumenttyp
--- | --- | --- | ---
26. November 2020 |  | 26.11.2020: Übereinkommen über ein Einheitliches Patentgericht PDF | 176 KB XLSX | 51 KB | Download
26. November 2020 |  | 26.11.2020: Europäische Bank für nachhaltige Entwicklung (Beschlussempfehlung) PDF | 176 KB XLSX | 51 KB | Download
20. November 2020 |  | 18.11.2020: Corona-Maßnahmen (epidemische Lage), Antrag CDU/CSU, SPD PDF | 176 KB XLSX | 52 KB | Download
20. November 2020 |  | 18.11.2020: Corona-Maßnahmen (epidemische Lage), Änderungsantrag FDP PDF | 176 KB XLSX | 51 KB | Download
20. November 2020 |  | 18.11.2020: Corona-Maßnahmen (epidemische Lage), Änderungsantrag Bündnis 90/Die Grünen PDF | 176 KB XLSX | 51 KB | Download
19. November 2020 |  | 19.11.2020: Energiesicherheit gewährleisten - Nord Stream 2 unterstützen (Beschlussempfehlung) PDF | 176 KB XLSX | 51 KB | Download
18. November 2020 |  | 18.11.2020: Corona-Maßnahmen (epidemische Lage), Gesetzentwurf CDU/CSU, SPD PDF | 176 KB XLSX | 51 KB | Download
30. Oktober 2020 |  | 30.10.2020: Untersuchungsausschuss Infektionsschutz - Abstrakte Normenkontrolle PDF | 176 KB XLSX | 44 KB | Download
30. Oktober 2020 |  | 30.10.2020: Einsetzung Untersuchungsausschuss Infektionsschutz PDF | 176 KB XLSX | 44 KB | Download
29. Oktober 2020 |  | 29.10.2020: Bundeswehreinsatz im Irak (Beschlussempfehlung) PDF | 20 KB XLSX | 44 KB | Download

Veröffentlichung | Thema | Dokumentname | Dokumenttyp
--- | --- | --- | ---
9. Oktober 2020 |  | 09.10.2020: Einführungsgesetz zur Abgabenordnung PDF | 177 KB XLSX | 52 KB | Download
9. Oktober 2020 |  | 09.10.2020: Finanzielle Lasten der Migrationspolitik umfassend offenlegen PDF | 177 KB XLSX | 55 KB | Download
9. Oktober 2020 |  | 09.10.2020: Bundeswahlgesetz (Wahlversammlungen) PDF | 176 KB XLSX | 52 KB | Download
8. Oktober 2020 |  | 08.10.2020: Bundeswahlgesetz PDF | 176 KB XLSX | 51 KB | Download
18. September 2020 |  | 18.09.2020: Konsequenzen aus dem Brand in Moria - Beschlussempfehlung 19/22579 zum Antrag 19/22264 PDF | 177 KB XLSX | 52 KB | Download
18. September 2020 |  | 18.09.2020: Konsequenzen aus dem Brand in Moria - Antrag 19/22679 PDF | 176 KB XLSX | 52 KB | Download
17. September 2020 |  | 17.09.2020: Finanzielle Entlastung der Kommunen PDF | 176 KB XLSX | 52 KB | Download
16. September 2020 |  | 16.09.2020: Mobilität der Zukunft (Beschlussempfehlung) PDF | 177 KB XLSX | 52 KB | Download
10. September 2020 |  | 10.09.2020: Abstrakte Normenkontrolle - Düngeverordnung (Beschlussempfehlung) PDF | 177 KB XLSX | 52 KB | Download
3. Juli 2020 |  | 03.07.2020: Bundeswahlgesetz (Geschäftsordnungsantrag) PDF | 177 KB XLSX | 52 KB | Download
3. Juli 2020 |  | 03.07.2020: Kohleausstiegsgesetz (Änderungsantrag 19/20730) PDF | 176 KB XLSX | 54 KB | Download
2. Juli 2020 |  | 02.07.2020: Corona-Konjunkturpaket (Entschließungsantrag 19/20739) PDF | 177 KB XLSX | 51 KB | Download
2. Juli 2020 |  | 02.07.2020: Corona-Konjunkturpaket (Beschlussempfehlung 19/20716) PDF | 176 KB XLSX | 51 KB | Download
19. Juni 2020 |  | 19.06.2020: Antiextremistischer Grundkonsens in Politik und Gesellschaft - Rechtsstaat und Demokratie schützen - Antifa ächten PDF | 176 KB XLSX | 44 KB | Download
18. Juni 2020 |  | 18.06.2020: Europäische Arbeitnehmerentsendung PDF | 176 KB XLSX | 52 KB | Download
17. Juni 2020 |  | 17.06.2020: Bundeswehreinsatz Libanon (UNIFIL) (Beschlussempfehlung) PDF | 178 KB XLSX | 51 KB | Download
17. Juni 2020 |  | 17.06.2020: Bundeswehr im Kosovo (KFOR) (Beschlussempfehlung) PDF | 178 KB XLSX | 52 KB | Download
29. Mai 2020 |  | 29.05.2020: Beschlussempfehlung zur Fortsetzung des Bundeswehreinsatzes EUTM Mali PDF | 176 KB XLSX | 52 KB | Download
29. Mai 2020 |  | 29.05.2020: Beschlussempfehlung zur Fortsetzung des Bundeswehreinsatzes in Mali (MINUSMA) PDF | 176 KB XLSX | 52 KB | Download
27. Mai 2020 |  | 27.05.2020: Beschlussempfehlung zu Operation ATALANTA PDF | 176 KB XLSX | 52 KB | Download
14. Mai 2020 |  | 14.05.2020: Bereitstellung des ESM-Instruments ECCL Pandemic Crisis Support (PCSI) PDF | 176 KB XLSX | 55 KB | Download
14. Mai 2020 |  | 14.05.2020: Zweites Gesetz zum Schutz der Bevölkerung bei einer epidemischen Lage von nationaler Tragweite PDF | 176 KB XLSX | 52 KB | Download
14. Mai 2020 |  | 14.05.2020: Beschlussempfehlung 19/19204 zu Corona-Aufschlag in der Grundsicherung das Existenzminimum sichern PDF | 176 KB XLSX | 51 KB | Download
14. Mai 2020 |  | 14.05.2020: Änderungsantrag 19/19221 zu Zweites Gesetz zum Schutz der Bevölkerung bei einer epidemischen Lage von nationaler Tragweite PDF | 176 KB XLSX | 51 KB | Download
7. Mai 2020 |  | 07.05.2020: Beschlussempfehlung zum Bundeswehreinsatz EUNAVFOR MED IRINI PDF | 176 KB XLSX | 52 KB | Download
25. März 2020 |  | 25.03.2020: Beschlussempfehlung zu Beschluss gemäß Artikel 115 Absatz 2 Satz 6 und 7 GG PDF | 176 KB XLSX | 51 KB | Download
13. März 2020 |  | 13.03.2020: Beschlussempfehlung zum Bundeswehreinsatz in Afghanistan PDF | 176 KB XLSX | 51 KB | Download
13. März 2020 |  | 13.03.2020: Beschlussempfehlung zum Bundeswehreinsatz SEA GUARDIAN PDF | 176 KB XLSX | 52 KB | Download
5. März 2020 |  | 04.03.2020: Beschlussempfehlung zu Humanitäres Aufnahmeprogramm für besonders schutzbedürftige Asylsuchende aus Griechenland PDF | 176 KB XLSX | 51 KB | Download
31. Januar 2020 |  | 30.01.2020: Antrag Schutz von Hinweisgebern auf EU-Ebene PDF | 177 KB XLSX | 51 KB | Download

2 / 71

- Facebook
- Twitter
- WhatsApp
- Mail
- Threema
- Telegram